world = {}

function world.load()
  world.clr = {30, 121, 159}

  world.meter = H/50 -- 14.4 pixels at H=720
  love.physics.setMeter(world.meter)
  world.g = H/3

  pWorld = love.physics.newWorld(0, world.g*world.meter, false)
  pWorld:setCallbacks(function(a, b, coll)
    if a ~= world.currentPlatform and a~= obj.player.fixture then
      world.currentPlatform = a
      ui.score = ui.score + 1
    elseif b ~= world.currentPlatform and b~= obj.player.fixture then
      world.currentPlatform = b
      ui.score = ui.score + 1
    end
  end)

  obj.platform = {}
  obj.platform.width = W/5
  obj.platform.maxH = H*0.2
  obj.platform.minH = H*0.8

  function obj.platform.getRandomY(n, h)
    return math.max(obj.platform.maxH+obj.platform[n].h/2, math.min(obj.platform.minH-obj.platform[n].h/2, obj.platform[n].body:getY() - obj.platform[n].h/2 + h/2 + love.math.random(-H/3, H/3)))
  end

  obj.platform[1] = {}
  obj.platform[1].w = obj.platform.width
  obj.platform[1].h = H
  obj.platform[1].body = love.physics.newBody(pWorld, W/5, H)
  obj.platform[1].shape = love.physics.newRectangleShape(obj.platform.width, H)

  obj.platform[2] = {}
  obj.platform[2].w = obj.platform.width
  obj.platform[2].h = H
  obj.platform[2].body = love.physics.newBody(pWorld, W - W/5, obj.platform.getRandomY(1, H))
  obj.platform[2].shape = love.physics.newRectangleShape(obj.platform.width, H)

  for n = 1, 2, 1 do
    obj.platform[n].fixture = love.physics.newFixture(obj.platform[n].body, obj.platform[n].shape)
    obj.platform[n].short = false
    obj.platform[n].slippery = false
    obj.platform[n].timed = false
  end

  world.currentPlatform = obj.platform[1].fixture
end

function world.update(dt)
  pWorld:update(dt)

  for n = 1, 2, 1 do
    if obj.platform[n].body:getX() < obj.player.body:getX()-obj.platform.width/2-player.onScreenX then
      -- Decide on the type of platform
      if love.math.random(1, 4) == 1 then
        obj.platform[n].short = true
      end
      if love.math.random(1, 4) == 1 then
        obj.platform[n].slippery = true
      end
      if love.math.random(1, 4) == 1 then
        obj.platform[n].timed = true
      end
      if obj.platform[n+1] ~= nil then
        obj.platform.prevID = n+1
      else
        obj.platform.prevID = n-1
      end

      -- Setting the default width and height in case its a normal platform
      obj.platform[n].w = obj.platform.width
      obj.platform[n].h = H
      if obj.platform[n].short then
        obj.platform[n].w = obj.platform.width*0.7
      end
      if obj.platform[n].timed then
        obj.platform[n].h = H/20
      end

      obj.platform[n].body:destroy()
      obj.platform[n].body = love.physics.newBody(pWorld, obj.platform[obj.platform.prevID].body:getX()+W*3/5, obj.platform.getRandomY(obj.platform.prevID, obj.platform[n].h))
      obj.platform[n].shape = love.physics.newRectangleShape(obj.platform[n].w, obj.platform[n].h)
      obj.platform[n].fixture = love.physics.newFixture(obj.platform[n].body, obj.platform[n].shape)

      if obj.platform[n].slippery then
        obj.platform[n].fixture:setFriction(0.8)
      else
        obj.platform[n].fixture:setFriction(1)
      end
    end

    obj.platform[n].drawPoints = {obj.platform[n].body:getWorldPoints(obj.platform[n].shape:getPoints())}

    -- Horisontally translating the platform
    for i = 1, 8, 2 do
      obj.platform[n].drawPoints[i] = obj.platform[n].drawPoints[i] - obj.player.body:getX() + player.onScreenX
    end
  end
end

function world.draw()
  love.graphics.setColor(world.clr)
  love.graphics.rectangle('fill', 0, 0, W, H)

  for n = 1, 2, 1 do
    love.graphics.setColor(191, 64*n, 219*n)
    love.graphics.polygon("fill", obj.platform[n].drawPoints)
  end
end
